.. Time-stamp: <12-Feb-2011 13:11:22 PST by rich@noir.com>

Welcome to cpiofile!

Cpiofile is a pure python implementation of a library which reads and
writes unix style "cpio" archives.

Current features:

* In initial development...

--rich
